#include "TKheaders.h"
#include "TK_2HSLHT.h"

#define NRAY 49   /* number of Anglebin in one scan */
#define NBIN 80  /* number of Rangebin in one Anglebin */

int main(int argc, char *argv[]){

    /* declare Data struct */
    TKINFO granuleHandle2HSLHT;
    L2HSLHT_SWATH  L2HSLHT;

    /* declare character */
    char job[256];
    char inputfile[256];

    strcpy(job, argv[1]);
    strcpy(inputfile, argv[2]);


    /* declare variables */
    int year, month, date, dayOfMon, hour, min;
    int i, j, k;
    int numOfScan;   
    int status;
 
    /* declare array */
    float lat[NRAY], lon[NRAY];
    float latentHeating[NRAY][NBIN];

    /* HDF file open */
    status = TKopen(inputfile, "2HSLHT", TKREAD, "HDF5", job, &granuleHandle2HSLHT, 1);
    if(status != TK_SUCCESS) {
        fprintf(stderr, "error:file open error[%s] input2HSLHT\n", inputfile);
    }
    
    /* META data read */
    status = TKgetMetaInt(&granuleHandle2HSLHT, "SwathHeader",
                            "NumberScansGranule", &numOfScan);
    if(status != TK_SUCCESS) {
         fprintf(stderr, "error:file read error[%s]\n", inputfile);
    }

    /* Scan data read */
    for (i=0; i<numOfScan; i++){
      status = TKreadScan( &granuleHandle2HSLHT, &L2HSLHT);

      /* Scantime Read */
      year      = L2HSLHT.ScanTime.Year;
      month     = L2HSLHT.ScanTime.Month;
      dayOfMon  = L2HSLHT.ScanTime.DayOfMonth;
      hour      = L2HSLHT.ScanTime.Hour;
      min       = L2HSLHT.ScanTime.Minute;

      for (j=0; j<NRAY; j++){

	    /* Latitude and Longitude Read */
        lat[j]  = L2HSLHT.Latitude[j];
        lon[j]  = L2HSLHT.Longitude[j];

        /* latentHeating Read */
        for (k=0; k<NBIN; k++){
          latentHeating[j][k] = L2HSLHT.latentHeating[j][k];
        }

	      /* Print the value */
	      if(i == 2048 && j == 20){
	        printf("Scan=%d, Angle=%d\n", i, j);
	        printf("lat=%f, lon=%f\n", lat[j], lon[j]);
          printf("latentHeating= %f (K/hr)\n", latentHeating[j][40]);
	      } 
      }
    }

    /* HDF File close*/
    status = TKclose(&granuleHandle2HSLHT);

    return 0;
}

