#include "TKheaders.h"
#include "TK_2APR.h"

int main(int argc, char *argv[]){

    /* declare Data struct */
    TKINFO granuleHandle2APR;
    L2APR_FS  L2APR;

    /* declare character */
    char job[256];
    char inputfile[256];

    strcpy(job, argv[1]);
    strcpy(inputfile, argv[2]);


    /* declare variables */
    int year, month, dayOfMon, hour, min;
    int i, j, k;
    int numOfScan;   
    int status;
 
    /* declare array */
    float lat[49], lon[49], precipRateESurface[49];
    float precipWater[49][176];

    /* HDF file open */
    status = TKopen(inputfile, "2APR", TKREAD, "HDF5", job, &granuleHandle2APR, 1);
    if(status != TK_SUCCESS) {
        fprintf(stderr, "error:file open error[%s] input2APR\n", inputfile);
    }
    
    /* META data read */
    status = TKgetMetaInt(&granuleHandle2APR, "SwathHeader",
                            "NumberScansGranule", &numOfScan);
    if(status != TK_SUCCESS) {
         fprintf(stderr, "error:file read error[%s]\n", inputfile);
    }

    /* Scan data read */
    for (i=0; i<numOfScan; i++){
      status = TKreadScan( &granuleHandle2APR, &L2APR);

      /* Scantime Read */
      year      = L2APR.ScanTime.Year;
      month     = L2APR.ScanTime.Month;
      dayOfMon  = L2APR.ScanTime.DayOfMonth;
      hour      = L2APR.ScanTime.Hour;
      min       = L2APR.ScanTime.Minute;

      for (j=0; j<49; j++){

	      /* Latitude and Longitude Read */
        lat[j]  = L2APR.Latitude[j];
        lon[j]  = L2APR.Longitude[j];

	      /* precipRateESurface Read */
        precipRateESurface[j] = L2APR.SLV.precipRateESurface[j];

	      /* Print the value */
	      if(i == 1978 && j == 5){
	        printf("Scan=%d, Angle=%d\n", i, j);
	        printf("lat=%f, lon=%f\n", lat[j], lon[j]);
	        printf("precipRateESurface= %f (mm/hr)\n", precipRateESurface[j]);

          for (k=0; k<176; k++){
            precipWater[j][k] = L2APR.SLV.precipWater[j][k];
	          if(k == 150){
	            printf("precipWater[%d][%d]= %f (g/m^3)\n", j,k,precipWater[j][k]);
	          } 
	        } 
	      } 
      }
    }

    /* HDF File close*/
    status = TKclose(&granuleHandle2APR);

    return 0;
}

